@@ -29,6 +29,7 @@ pub use role::RoleExt;
 pub use role_binding::RoleBindingExt;
 pub use role_ref::RoleRefExt;
 pub use secret::SecretExt;
+pub use secret_env_source::SecretEnvSourceExt;
 pub use secret_volume_source::SecretVolumeSourceExt;
 pub use service::ServiceExt;
 pub use service_account::ServiceAccountExt;
@@ -54,6 +55,7 @@ mod role;
 mod role_binding;
 mod role_ref;
 mod secret;
+mod secret_env_source;
 mod secret_volume_source;
 mod service;
 mod service_account;
