@@ -1,5 +1,9 @@
+//
+// Copyright (c) 2022 RepliXio Ltd. All rights reserved.
+// Use is subject to license terms.
+//
+
 use anyhow::Context;
-use k8s_cluster_api::v1beta1 as capiv1;
 use kube::config;
 
 use super::*;
